# This file was auto-generated by Fern from our API Definition.

import typing

WebhookEventChatStatus = typing.Union[
    typing.Literal[
        "ACTIVE", "USER_ENDED", "USER_TIMEOUT", "INACTIVITY_TIMEOUT", "MAX_DURATION_TIMEOUT", "SILENCE_TIMEOUT", "ERROR"
    ],
    typing.Any,
]
