# This file was auto-generated by Fern from our API Definition.

import typing

from .assistant_end import AssistantEnd
from .assistant_message import AssistantMessage
from .assistant_prosody import AssistantProsody
from .audio_output import AudioOutput
from .chat_metadata import ChatMetadata
from .session_settings import SessionSettings
from .tool_call_message import ToolCallMessage
from .tool_error_message import ToolErrorMessage
from .tool_response_message import ToolResponseMessage
from .user_interruption import UserInterruption
from .user_message import UserMessage
from .web_socket_error import WebSocketError

SubscribeEvent = typing.Union[
    AssistantEnd,
    AssistantMessage,
    AssistantProsody,
    AudioOutput,
    ChatMetadata,
    WebSocketError,
    UserInterruption,
    UserMessage,
    ToolCallMessage,
    ToolResponseMessage,
    ToolErrorMessage,
    SessionSettings,
]
