# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .return_chat_audio_reconstruction_status import ReturnChatAudioReconstructionStatus


class ReturnChatAudioReconstruction(UniversalBaseModel):
    """
    List of chat audio reconstructions returned for the specified page number and page size.
    """

    filename: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the chat audio reconstruction file.
    """

    id: str = pydantic.Field()
    """
    Identifier for the chat. Formatted as a UUID.
    """

    modified_at: typing.Optional[int] = pydantic.Field(default=None)
    """
    The timestamp of the most recent status change for this audio reconstruction, formatted milliseconds since the Unix epoch.
    """

    signed_audio_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Signed URL used to download the chat audio reconstruction file.
    """

    signed_url_expiration_timestamp_millis: typing.Optional[int] = pydantic.Field(default=None)
    """
    The timestamp when the signed URL will expire, formatted as a Unix epoch milliseconds.
    """

    status: ReturnChatAudioReconstructionStatus
    user_id: str = pydantic.Field()
    """
    Identifier for the user that owns this chat. Formatted as a UUID.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
