# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .voice_provider import VoiceProvider


class ReturnVoice(UniversalBaseModel):
    """
    An Octave voice available for text-to-speech
    """

    compatible_octave_models: typing.Optional[typing.List[str]] = None
    id: str = pydantic.Field()
    """
    ID of the voice in the `Voice Library`.
    """

    name: str = pydantic.Field()
    """
    Name of the voice in the `Voice Library`.
    """

    provider: VoiceProvider

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
