# This file was auto-generated by Fern from our API Definition.

import typing

from .assistant_input import AssistantInput
from .pause_assistant_message import PauseAssistantMessage
from .resume_assistant_message import ResumeAssistantMessage
from .session_settings import SessionSettings
from .tool_error_message import ToolErrorMessage
from .tool_response_message import ToolResponseMessage
from .user_input import UserInput

ControlPlanePublishEvent = typing.Union[
    SessionSettings,
    UserInput,
    AssistantInput,
    ToolResponseMessage,
    ToolErrorMessage,
    PauseAssistantMessage,
    ResumeAssistantMessage,
]
