# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class PostedNudgeSpec(UniversalBaseModel):
    """
    A nudge specification posted to the server
    """

    enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If true, EVI will 'nudge' the user to speak after a determined interval of silence.
    """

    interval_secs: typing.Optional[int] = pydantic.Field(default=None)
    """
    The interval of inactivity (in seconds) before a nudge is triggered.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
