# This file was auto-generated by Fern from our API Definition.

import typing

from .posted_utterance_voice_with_id import PostedUtteranceVoiceWithId
from .posted_utterance_voice_with_name import PostedUtteranceVoiceWithName

PostedUtteranceVoice = typing.Union[PostedUtteranceVoiceWithId, PostedUtteranceVoiceWithName]
