# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        Alternative,
        Bcp47Tag,
        BoundingBox,
        BurstPrediction,
        Classification,
        CompletedEmbeddingGeneration,
        CompletedInference,
        CompletedState,
        CompletedTlInference,
        CompletedTraining,
        CustomModel,
        CustomModelId,
        CustomModelPrediction,
        CustomModelRequest,
        CustomModelVersionId,
        CustomModelsInferenceJob,
        CustomModelsTrainingJob,
        Dataset,
        DatasetId,
        DatasetVersionId,
        DescriptionsScore,
        Direction,
        EmbeddingGenerationBaseRequest,
        EmbeddingGenerationJob,
        EmotionScore,
        Error,
        EvaluationArgs,
        Face,
        FacePrediction,
        FacemeshPrediction,
        FacsScore,
        Failed,
        FailedState,
        File,
        Granularity,
        GroupedPredictionsBurstPrediction,
        GroupedPredictionsFacePrediction,
        GroupedPredictionsFacemeshPrediction,
        GroupedPredictionsLanguagePrediction,
        GroupedPredictionsNerPrediction,
        GroupedPredictionsProsodyPrediction,
        InProgress,
        InProgressState,
        InferenceBaseRequest,
        InferenceJob,
        InferencePrediction,
        InferenceRequest,
        InferenceResults,
        InferenceSourcePredictResult,
        JobEmbeddingGeneration,
        JobId,
        JobInference,
        JobTlInference,
        JobTraining,
        Language,
        LanguagePrediction,
        Models,
        ModelsPredictions,
        Ner,
        NerPrediction,
        Null,
        PositionInterval,
        PredictionsOptionalNullBurstPrediction,
        PredictionsOptionalNullFacePrediction,
        PredictionsOptionalNullFacemeshPrediction,
        PredictionsOptionalTranscriptionMetadataLanguagePrediction,
        PredictionsOptionalTranscriptionMetadataNerPrediction,
        PredictionsOptionalTranscriptionMetadataProsodyPrediction,
        Prosody,
        ProsodyPrediction,
        Queued,
        QueuedState,
        RegistryFileDetail,
        Regression,
        SentimentScore,
        SortBy,
        Source,
        SourceFile,
        SourceTextSource,
        SourceUrl,
        Source_File,
        Source_Text,
        Source_Url,
        StateEmbeddingGeneration,
        StateEmbeddingGenerationCompletedEmbeddingGeneration,
        StateEmbeddingGenerationFailed,
        StateEmbeddingGenerationInProgress,
        StateEmbeddingGenerationQueued,
        StateEmbeddingGeneration_Completed,
        StateEmbeddingGeneration_Failed,
        StateEmbeddingGeneration_InProgress,
        StateEmbeddingGeneration_Queued,
        StateInference,
        StateInference_Completed,
        StateInference_Failed,
        StateInference_InProgress,
        StateInference_Queued,
        StateTlInference,
        StateTlInferenceCompletedTlInference,
        StateTlInferenceFailed,
        StateTlInferenceInProgress,
        StateTlInferenceQueued,
        StateTlInference_Completed,
        StateTlInference_Failed,
        StateTlInference_InProgress,
        StateTlInference_Queued,
        StateTraining,
        StateTrainingCompletedTraining,
        StateTrainingFailed,
        StateTrainingInProgress,
        StateTrainingQueued,
        StateTraining_Completed,
        StateTraining_Failed,
        StateTraining_InProgress,
        StateTraining_Queued,
        Status,
        Tag,
        Target,
        Task,
        TaskClassification,
        TaskRegression,
        Task_Classification,
        Task_Regression,
        TextSource,
        TimeInterval,
        TlInferenceBaseRequest,
        TlInferencePrediction,
        TlInferenceResults,
        TlInferenceSourcePredictResult,
        ToxicityScore,
        TrainingBaseRequest,
        TrainingCustomModel,
        Transcription,
        TranscriptionMetadata,
        Type,
        Unconfigurable,
        UnionJob,
        UnionPredictResult,
        Url,
        ValidationArgs,
        When,
        Window,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "Alternative": ".types",
    "Bcp47Tag": ".types",
    "BoundingBox": ".types",
    "BurstPrediction": ".types",
    "Classification": ".types",
    "CompletedEmbeddingGeneration": ".types",
    "CompletedInference": ".types",
    "CompletedState": ".types",
    "CompletedTlInference": ".types",
    "CompletedTraining": ".types",
    "CustomModel": ".types",
    "CustomModelId": ".types",
    "CustomModelPrediction": ".types",
    "CustomModelRequest": ".types",
    "CustomModelVersionId": ".types",
    "CustomModelsInferenceJob": ".types",
    "CustomModelsTrainingJob": ".types",
    "Dataset": ".types",
    "DatasetId": ".types",
    "DatasetVersionId": ".types",
    "DescriptionsScore": ".types",
    "Direction": ".types",
    "EmbeddingGenerationBaseRequest": ".types",
    "EmbeddingGenerationJob": ".types",
    "EmotionScore": ".types",
    "Error": ".types",
    "EvaluationArgs": ".types",
    "Face": ".types",
    "FacePrediction": ".types",
    "FacemeshPrediction": ".types",
    "FacsScore": ".types",
    "Failed": ".types",
    "FailedState": ".types",
    "File": ".types",
    "Granularity": ".types",
    "GroupedPredictionsBurstPrediction": ".types",
    "GroupedPredictionsFacePrediction": ".types",
    "GroupedPredictionsFacemeshPrediction": ".types",
    "GroupedPredictionsLanguagePrediction": ".types",
    "GroupedPredictionsNerPrediction": ".types",
    "GroupedPredictionsProsodyPrediction": ".types",
    "InProgress": ".types",
    "InProgressState": ".types",
    "InferenceBaseRequest": ".types",
    "InferenceJob": ".types",
    "InferencePrediction": ".types",
    "InferenceRequest": ".types",
    "InferenceResults": ".types",
    "InferenceSourcePredictResult": ".types",
    "JobEmbeddingGeneration": ".types",
    "JobId": ".types",
    "JobInference": ".types",
    "JobTlInference": ".types",
    "JobTraining": ".types",
    "Language": ".types",
    "LanguagePrediction": ".types",
    "Models": ".types",
    "ModelsPredictions": ".types",
    "Ner": ".types",
    "NerPrediction": ".types",
    "Null": ".types",
    "PositionInterval": ".types",
    "PredictionsOptionalNullBurstPrediction": ".types",
    "PredictionsOptionalNullFacePrediction": ".types",
    "PredictionsOptionalNullFacemeshPrediction": ".types",
    "PredictionsOptionalTranscriptionMetadataLanguagePrediction": ".types",
    "PredictionsOptionalTranscriptionMetadataNerPrediction": ".types",
    "PredictionsOptionalTranscriptionMetadataProsodyPrediction": ".types",
    "Prosody": ".types",
    "ProsodyPrediction": ".types",
    "Queued": ".types",
    "QueuedState": ".types",
    "RegistryFileDetail": ".types",
    "Regression": ".types",
    "SentimentScore": ".types",
    "SortBy": ".types",
    "Source": ".types",
    "SourceFile": ".types",
    "SourceTextSource": ".types",
    "SourceUrl": ".types",
    "Source_File": ".types",
    "Source_Text": ".types",
    "Source_Url": ".types",
    "StateEmbeddingGeneration": ".types",
    "StateEmbeddingGenerationCompletedEmbeddingGeneration": ".types",
    "StateEmbeddingGenerationFailed": ".types",
    "StateEmbeddingGenerationInProgress": ".types",
    "StateEmbeddingGenerationQueued": ".types",
    "StateEmbeddingGeneration_Completed": ".types",
    "StateEmbeddingGeneration_Failed": ".types",
    "StateEmbeddingGeneration_InProgress": ".types",
    "StateEmbeddingGeneration_Queued": ".types",
    "StateInference": ".types",
    "StateInference_Completed": ".types",
    "StateInference_Failed": ".types",
    "StateInference_InProgress": ".types",
    "StateInference_Queued": ".types",
    "StateTlInference": ".types",
    "StateTlInferenceCompletedTlInference": ".types",
    "StateTlInferenceFailed": ".types",
    "StateTlInferenceInProgress": ".types",
    "StateTlInferenceQueued": ".types",
    "StateTlInference_Completed": ".types",
    "StateTlInference_Failed": ".types",
    "StateTlInference_InProgress": ".types",
    "StateTlInference_Queued": ".types",
    "StateTraining": ".types",
    "StateTrainingCompletedTraining": ".types",
    "StateTrainingFailed": ".types",
    "StateTrainingInProgress": ".types",
    "StateTrainingQueued": ".types",
    "StateTraining_Completed": ".types",
    "StateTraining_Failed": ".types",
    "StateTraining_InProgress": ".types",
    "StateTraining_Queued": ".types",
    "Status": ".types",
    "Tag": ".types",
    "Target": ".types",
    "Task": ".types",
    "TaskClassification": ".types",
    "TaskRegression": ".types",
    "Task_Classification": ".types",
    "Task_Regression": ".types",
    "TextSource": ".types",
    "TimeInterval": ".types",
    "TlInferenceBaseRequest": ".types",
    "TlInferencePrediction": ".types",
    "TlInferenceResults": ".types",
    "TlInferenceSourcePredictResult": ".types",
    "ToxicityScore": ".types",
    "TrainingBaseRequest": ".types",
    "TrainingCustomModel": ".types",
    "Transcription": ".types",
    "TranscriptionMetadata": ".types",
    "Type": ".types",
    "Unconfigurable": ".types",
    "UnionJob": ".types",
    "UnionPredictResult": ".types",
    "Url": ".types",
    "ValidationArgs": ".types",
    "When": ".types",
    "Window": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Alternative",
    "Bcp47Tag",
    "BoundingBox",
    "BurstPrediction",
    "Classification",
    "CompletedEmbeddingGeneration",
    "CompletedInference",
    "CompletedState",
    "CompletedTlInference",
    "CompletedTraining",
    "CustomModel",
    "CustomModelId",
    "CustomModelPrediction",
    "CustomModelRequest",
    "CustomModelVersionId",
    "CustomModelsInferenceJob",
    "CustomModelsTrainingJob",
    "Dataset",
    "DatasetId",
    "DatasetVersionId",
    "DescriptionsScore",
    "Direction",
    "EmbeddingGenerationBaseRequest",
    "EmbeddingGenerationJob",
    "EmotionScore",
    "Error",
    "EvaluationArgs",
    "Face",
    "FacePrediction",
    "FacemeshPrediction",
    "FacsScore",
    "Failed",
    "FailedState",
    "File",
    "Granularity",
    "GroupedPredictionsBurstPrediction",
    "GroupedPredictionsFacePrediction",
    "GroupedPredictionsFacemeshPrediction",
    "GroupedPredictionsLanguagePrediction",
    "GroupedPredictionsNerPrediction",
    "GroupedPredictionsProsodyPrediction",
    "InProgress",
    "InProgressState",
    "InferenceBaseRequest",
    "InferenceJob",
    "InferencePrediction",
    "InferenceRequest",
    "InferenceResults",
    "InferenceSourcePredictResult",
    "JobEmbeddingGeneration",
    "JobId",
    "JobInference",
    "JobTlInference",
    "JobTraining",
    "Language",
    "LanguagePrediction",
    "Models",
    "ModelsPredictions",
    "Ner",
    "NerPrediction",
    "Null",
    "PositionInterval",
    "PredictionsOptionalNullBurstPrediction",
    "PredictionsOptionalNullFacePrediction",
    "PredictionsOptionalNullFacemeshPrediction",
    "PredictionsOptionalTranscriptionMetadataLanguagePrediction",
    "PredictionsOptionalTranscriptionMetadataNerPrediction",
    "PredictionsOptionalTranscriptionMetadataProsodyPrediction",
    "Prosody",
    "ProsodyPrediction",
    "Queued",
    "QueuedState",
    "RegistryFileDetail",
    "Regression",
    "SentimentScore",
    "SortBy",
    "Source",
    "SourceFile",
    "SourceTextSource",
    "SourceUrl",
    "Source_File",
    "Source_Text",
    "Source_Url",
    "StateEmbeddingGeneration",
    "StateEmbeddingGenerationCompletedEmbeddingGeneration",
    "StateEmbeddingGenerationFailed",
    "StateEmbeddingGenerationInProgress",
    "StateEmbeddingGenerationQueued",
    "StateEmbeddingGeneration_Completed",
    "StateEmbeddingGeneration_Failed",
    "StateEmbeddingGeneration_InProgress",
    "StateEmbeddingGeneration_Queued",
    "StateInference",
    "StateInference_Completed",
    "StateInference_Failed",
    "StateInference_InProgress",
    "StateInference_Queued",
    "StateTlInference",
    "StateTlInferenceCompletedTlInference",
    "StateTlInferenceFailed",
    "StateTlInferenceInProgress",
    "StateTlInferenceQueued",
    "StateTlInference_Completed",
    "StateTlInference_Failed",
    "StateTlInference_InProgress",
    "StateTlInference_Queued",
    "StateTraining",
    "StateTrainingCompletedTraining",
    "StateTrainingFailed",
    "StateTrainingInProgress",
    "StateTrainingQueued",
    "StateTraining_Completed",
    "StateTraining_Failed",
    "StateTraining_InProgress",
    "StateTraining_Queued",
    "Status",
    "Tag",
    "Target",
    "Task",
    "TaskClassification",
    "TaskRegression",
    "Task_Classification",
    "Task_Regression",
    "TextSource",
    "TimeInterval",
    "TlInferenceBaseRequest",
    "TlInferencePrediction",
    "TlInferenceResults",
    "TlInferenceSourcePredictResult",
    "ToxicityScore",
    "TrainingBaseRequest",
    "TrainingCustomModel",
    "Transcription",
    "TranscriptionMetadata",
    "Type",
    "Unconfigurable",
    "UnionJob",
    "UnionPredictResult",
    "Url",
    "ValidationArgs",
    "When",
    "Window",
]
