# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations


class HumeClientEnvironment:
    PROD: HumeClientEnvironment

    def __init__(self, *, base: str, evi: str, tts: str, stream: str):
        self.base = base
        self.evi = evi
        self.tts = tts
        self.stream = stream


HumeClientEnvironment.PROD = HumeClientEnvironment(
    base="https://api.hume.ai",
    evi="wss://api.hume.ai/v0/evi",
    tts="wss://api.hume.ai/v0/tts",
    stream="wss://api.hume.ai/v0/stream",
)
