# This file was auto-generated by Fern from our API Definition.

import typing

LanguageModelType = typing.Union[
    typing.Literal[
        "claude-3-7-sonnet-latest",
        "claude-3-5-sonnet-latest",
        "claude-3-5-haiku-latest",
        "claude-3-5-sonnet-20240620",
        "claude-3-opus-20240229",
        "claude-3-sonnet-20240229",
        "claude-3-haiku-20240307",
        "claude-sonnet-4-20250514",
        "claude-sonnet-4-5-20250929",
        "claude-haiku-4-5-20251001",
        "us.anthropic.claude-3-5-haiku-20241022-v1:0",
        "us.anthropic.claude-3-5-sonnet-20240620-v1:0",
        "us.anthropic.claude-3-haiku-20240307-v1:0",
        "gpt-oss-120b",
        "qwen-3-235b-a22b",
        "qwen-3-235b-a22b-instruct-2507",
        "qwen-3-235b-a22b-thinking-2507",
        "gemini-1.5-pro",
        "gemini-1.5-flash",
        "gemini-1.5-pro-002",
        "gemini-1.5-flash-002",
        "gemini-2.0-flash",
        "gemini-2.5-flash",
        "gemini-2.5-flash-preview-04-17",
        "gpt-4-turbo",
        "gpt-4-turbo-preview",
        "gpt-3.5-turbo-0125",
        "gpt-3.5-turbo",
        "gpt-4o",
        "gpt-4o-mini",
        "gpt-4.1",
        "gpt-5",
        "gpt-5-mini",
        "gpt-5-nano",
        "gpt-4o-priority",
        "gpt-4o-mini-priority",
        "gpt-4.1-priority",
        "gpt-5-priority",
        "gpt-5-mini-priority",
        "gpt-5-nano-priority",
        "gemma-7b-it",
        "llama3-8b-8192",
        "llama3-70b-8192",
        "llama-3.1-70b-versatile",
        "llama-3.3-70b-versatile",
        "llama-3.1-8b-instant",
        "moonshotai/kimi-k2-instruct",
        "accounts/fireworks/models/mixtral-8x7b-instruct",
        "accounts/fireworks/models/llama-v3p1-405b-instruct",
        "accounts/fireworks/models/llama-v3p1-70b-instruct",
        "accounts/fireworks/models/llama-v3p1-8b-instruct",
        "sonar",
        "sonar-pro",
        "sambanova",
        "DeepSeek-R1-Distill-Llama-70B",
        "Llama-4-Maverick-17B-128E-Instruct",
        "Qwen3-32B",
        "grok-4-fast-non-reasoning-latest",
        "ellm",
        "custom-language-model",
        "hume-evi-3-web-search",
    ],
    typing.Any,
]
