# This file was auto-generated by Fern from our API Definition.

import typing

ReturnChatEventType = typing.Union[
    typing.Literal[
        "FUNCTION_CALL",
        "FUNCTION_CALL_RESPONSE",
        "CHAT_END_MESSAGE",
        "AGENT_MESSAGE",
        "SYSTEM_PROMPT",
        "USER_RECORDING_START_MESSAGE",
        "RESUME_ONSET",
        "USER_INTERRUPTION",
        "CHAT_START_MESSAGE",
        "PAUSE_ONSET",
        "USER_MESSAGE",
    ],
    typing.Any,
]
