# This file was auto-generated by Fern from our API Definition.

import typing

from .snippet_audio_chunk import SnippetAudioChunk
from .timestamp_message import TimestampMessage

TtsOutput = typing.Union[SnippetAudioChunk, TimestampMessage]
