# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .millisecond_interval import MillisecondInterval
from .timestamp_type import TimestampType


class Timestamp(UniversalBaseModel):
    text: str = pydantic.Field()
    """
    The word or phoneme text that the timestamp corresponds to.
    """

    time: MillisecondInterval = pydantic.Field()
    """
    The start and end timestamps for the word or phoneme in milliseconds.
    """

    type: TimestampType

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
